==> apacheds-noarch-installer-1.5.4-sources.jar: org/apache/directory/server/UberjarMain.java <==
/*
 *  Licensed to the Apache Software Foundation (ASF) under one
 *  or more contributor license agreements.  See the NOTICE file
 *  distributed with this work for additional information
 *  regarding copyright ownership.  The ASF licenses this file
 *  to you under the Apache License, Version 2.0 (the
 *  "License"); you may not use this file except in compliance
 *  with the License.  You may obtain a copy of the License at
 *  
 *    http://www.apache.org/licenses/LICENSE-2.0
 *  
 *  Unless required by applicable law or agreed to in writing,
 *  software distributed under the License is distributed on an
 *  "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 *  KIND, either express or implied.  See the License for the
 *  specific language governing permissions and limitations
 *  under the License. 
 *  
 */
package org.apache.directory.server;


import org.apache.directory.daemon.InstallationLayout;

import java.io.File;


/**
 * The command line main for the server.  Warning this used to be a simple test
 * case so there really is not much here.
 *
 * @author <a href="mailto:dev@directory.apache.org">Apache Directory Project</a>
 * @version $Rev: 596814 $
 */
public class UberjarMain
{
    /**
     * Takes a single argument, the path to the installation home, which contains 
     * the configuration to load with server startup settings.
     *
     * @param args the arguments
     */
    public static void main( String[] args ) throws Exception
    {
        Service server = new Service();

        if ( args.length > 0 && new File( args[0] ).isDirectory() )
        {
            InstallationLayout layout = new InstallationLayout( args[0] );
            String confFile = layout.getConfigurationFile().toURI().toURL().toString();
            server.init( layout, new String[] { confFile } );
            server.start();
        }
        else if ( args.length > 0 && new File( args[0] ).isFile() )
        {
            server.init( null, args );
            server.start();
        }
        else
        {
            server.init( null, null );
            server.start();
        }
    }
}

==> apacheds-noarch-installer-1.5.5-sources.jar: org/apache/directory/server/UberjarMain.java <==
/*
 *  Licensed to the Apache Software Foundation (ASF) under one
 *  or more contributor license agreements.  See the NOTICE file
 *  distributed with this work for additional information
 *  regarding copyright ownership.  The ASF licenses this file
 *  to you under the Apache License, Version 2.0 (the
 *  "License"); you may not use this file except in compliance
 *  with the License.  You may obtain a copy of the License at
 *  
 *    http://www.apache.org/licenses/LICENSE-2.0
 *  
 *  Unless required by applicable law or agreed to in writing,
 *  software distributed under the License is distributed on an
 *  "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 *  KIND, either express or implied.  See the License for the
 *  specific language governing permissions and limitations
 *  under the License. 
 *  
 */
package org.apache.directory.server;


import org.apache.directory.daemon.InstallationLayout;

import java.io.File;


/**
 * The command line main for the server.  Warning this used to be a simple test
 * case so there really is not much here.
 *
 * @author <a href="mailto:dev@directory.apache.org">Apache Directory Project</a>
 * @version $Rev: 785329 $
 */
public class UberjarMain
{
    /**
     * Takes a single argument, the path to the installation home, which contains 
     * the configuration to load with server startup settings.
     *
     * @param args the arguments
     */
    public static void main( String[] args ) throws Exception
    {
        Service service = new Service();

        if ( args.length > 0 && new File( args[0] ).isDirectory() )
        {
            InstallationLayout layout = new InstallationLayout( args[0] );
            String confFile = layout.getConfigurationFile().toURI().toURL().toString();
            service.init( layout, new String[] { confFile } );
        }
        else if ( args.length > 0 && new File( args[0] ).isFile() )
        {
            service.init( null, args );
        }
        else
        {
            service.init( null, null );
        }
    }
}
